==> hlw-core-0.0.2-20250703.020012-78-sources.jar: cn/gtmap/hlw/core/dto/third/tdxx/TdsyqxxThirdResultDTO.java <==
package cn.gtmap.hlw.core.dto.third.tdxx;

import cn.gtmap.hlw.core.dto.third.cqxx.CqxxThirdQlrDTO;
import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2024/3/18
 * @description
 */
@Data
public class TdsyqxxThirdResultDTO {
    /**
     * 产权证号
     */
    private String fczh;

    /**
     * 不动产单元号
     */
    private String bdcdyh;

    /**
     * 坐落
     */
    private String zl;

    /**
     * 是否抵押（0是，1否）
     */
    private String sfdy;

    /**
     * 不动产单元编号
     */
    private String bdcdybh;

    /**
     * 是否查封（0是，1否）
     */
    private String sfcf;

    /**
     * 宗地用途
     */
    private String zdyt;

    /**
     * 宗地用途名称
     */
    private String zdytmc;

    /**
     * 宗地面积
     */
    private String zdmj;

    /**
     * 宗地权利性质
     */
    private String zdzhqlxz;

    /**
     * 宗地权利性质名称
     */
    private String zdzhqlxzmc;

    /**
     * 土地使用权类型
     */
    private String tdsyqlx;

    /**
     * 土地使用权类型名称
     */
    private String tdsyqlxmc;

    /**
     * 行政区划数字代码
     */
    private String xzqhszdm;

    /**
     * 登记时间
     */
    private String djsj;

    /**
     * 是否异议（0是，1否）
     */
    private String sfyy;

    /**
     * 附记
     */
    private String fj;

    /**
     * 土地使用起始时间
     */
    private String tdsyqssj;

    /**
     * 土地使用结束时间
     */
    private String tdsyjssj;

    /**
     * 独用土地面积
     */
    private String dytdmj;

    /**
     * 分摊土地面积
     */
    private String fttdmj;

    /**
     * 项目id
     */
    private String xmid;

    /**
     * 是否锁定（0是，1否）
     */
    private String sfsd;

    /**
     * 权利类型
     */
    private String qllx;

    /**
     * 权利类型名称
     */
    private String qllxmc;
    /**
     * 行政区代码
     */
    private String qydm;
    /**
     * 行政区代码名称
     */
    private String qymc;
    /**
     * 权利人
     */
    private List<CqxxThirdQlrDTO> qlrList;
}

==> hlw-core-0.0.2-20251205.085720-174-sources.jar: cn/gtmap/hlw/core/dto/third/tdxx/TdsyqxxThirdResultDTO.java <==
package cn.gtmap.hlw.core.dto.third.tdxx;

import cn.gtmap.hlw.core.dto.sqxx.save.CfxxDTO;
import cn.gtmap.hlw.core.dto.sqxx.save.DyxxDTO;
import cn.gtmap.hlw.core.dto.sqxx.save.YiyixxDTO;
import cn.gtmap.hlw.core.dto.third.cqxx.CqxxThirdQlrDTO;
import lombok.Data;

import java.util.List;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2024/3/18
 * @description
 */
@Data
public class TdsyqxxThirdResultDTO {
    /**
     * 产权证号
     */
    private String fczh;

    /**
     * 不动产单元号
     */
    private String bdcdyh;

    /**
     * 坐落
     */
    private String zl;

    /**
     * 是否抵押（0是，1否）
     */
    private String sfdy;

    /**
     * 不动产单元编号
     */
    private String bdcdybh;

    /**
     * 是否查封（0是，1否）
     */
    private String sfcf;

    /**
     * 宗地用途
     */
    private String zdyt;

    /**
     * 宗地用途名称
     */
    private String zdytmc;

    /**
     * 宗地面积
     */
    private String zdmj;

    /**
     * 宗地权利性质
     */
    private String zdzhqlxz;

    /**
     * 宗地权利性质名称
     */
    private String zdzhqlxzmc;

    /**
     * 土地使用权类型
     */
    private String tdsyqlx;

    /**
     * 土地使用权类型名称
     */
    private String tdsyqlxmc;

    /**
     * 行政区划数字代码
     */
    private String xzqhszdm;

    /**
     * 登记时间
     */
    private String djsj;

    /**
     * 是否异议（0是，1否）
     */
    private String sfyy;

    /**
     * 附记
     */
    private String fj;

    /**
     * 土地使用起始时间
     */
    private String tdsyqssj;

    /**
     * 土地使用结束时间
     */
    private String tdsyjssj;

    /**
     * 独用土地面积
     */
    private String dytdmj;

    /**
     * 分摊土地面积
     */
    private String fttdmj;

    /**
     * 项目id
     */
    private String xmid;

    /**
     * 是否锁定（0是，1否）
     */
    private String sfsd;

    /**
     * 权利类型
     */
    private String qllx;

    /**
     * 权利类型名称
     */
    private String qllxmc;
    /**
     * 行政区代码
     */
    private String qydm;
    /**
     * 行政区代码名称
     */
    private String qymc;
    /**
     * 权利人
     */
    private List<CqxxThirdQlrDTO> qlrList;

    /**
     * 抵押信息
     */
    private List<DyxxDTO> dyxxList;
    /**
     * 查封信息
     */
    private List<CfxxDTO> cfxxList;
    /**
     * 异议信息
     */
    private List<YiyixxDTO> yiyixxList;
}
